graphium.nn.pyg_layers
====================
Implementations of GNN layers based on PyG in the library

=== "Contents"

    * [Gated GCN Layer](#gated-gcn-layer)
    * [GPS Layer](#gps-layer)
    * [GIN and GINE Layers](#gin-and-gine-layers)
    * [MPNN Layer](#mpnn-layer)
    * [PNA Layer](#pna-layer)
    * [Pooling Layer](#pooling-layers)

## Gated GCN Layer
------------
::: graphium.nn.pyg_layers.gated_gcn_pyg


## GPS Layer
------------
::: graphium.nn.pyg_layers.gps_pyg


## GIN and GINE Layers
------------
::: graphium.nn.pyg_layers.gin_pyg


## MPNN Layer
------------
::: graphium.nn.pyg_layers.mpnn_pyg


## PNA Layer
------------
::: graphium.nn.pyg_layers.pna_pyg


## Pooling Layers
------------
::: graphium.nn.pyg_layers.pooling_pyg


## Utils
------------
::: graphium.nn.pyg_layers.utils
